@@ -1,8 +1,9 @@
 from Fishconsole import fcv
 from Fishconsole import logs
-from Fishconsole import helps
+from Fishconsole import update
 
-logs.系统日志("用户调用了tool模块")
+
+logs.系统日志("用户调用了Fishsys模块")
 # 导入强制更新系统所需要的内容
 PI = fcv.f_debug()
 PI = PI["PI"]
@@ -14,6 +15,21 @@ filecheck = fcv.f_debug()
 filecheck = filecheck["filecheck"]
 
 
+def 强制类型检测(任意变量,预期类型):
+    type值=str(type(任意变量))
+    变量类型=type值.split("'")[1]
+    logs.系统日志(f"强制类型检测》展示提取出的变量类型》{变量类型}")
+    if 变量类型==预期类型:
+        logs.系统日志(f"强制类型检测》目标判断为真")
+        return True
+    else:
+        logs.系统日志(f"强制类型检测》目标判断为假")
+        return False
+
+
+
+
+
 # 这是一座屎山，能修则修，不能修就算了
 # 模式,加密密码,内容
 def passwordsys(模式: any, id_protect: str, password_a: str):
@@ -39,14 +55,14 @@ def passwordsys(模式: any, id_protect: str, password_a: str):
         for a in password:
             res_a = res_a + a
             if a == "@":
-                print(logs.颜色(logs.日志("你的密码中不允许有@符号，请重新输入"), 色选="红色"))
-                exit()
+                print(logs.颜色(logs.日志(""), 色选="红色"))
+                logs.安全退出("你的密码中不允许有@符号，请重新输入")
 
         for b in id_protect:
             res_b = res_b + b
             if b == "@":
-                print(logs.颜色(logs.日志("你的原文中不允许有@符号，请重新输入"), 色选="红色"))
-                exit()
+                logs.安全退出(logs.日志("你的原文中不允许有@符号，请重新输入", 色选="红色"))
+
         else:
             logs.系统日志("确认成功", PI)
         logs.系统日志("转移变量的数据", PI)
@@ -277,9 +293,7 @@ def passwordsys(模式: any, id_protect: str, password_a: str):
                 jiami_last = jiami_last + "bff"
                 count = count + 1
         if count == 1:
-            print(logs.日志("你没有输入任何内容", 色选="红色"))
-            print(logs.日志("你输入了非法字符（除1-0，a-z，空格以外其他全是），请检查后重新开始，加密失败", 色选="红色"))
-            exit()
+            logs.安全退出(logs.日志("你输入了非法字符（除1-0，a-z，空格以外其他全是），请检查后重新开始，加密失败", 色选="红色"))
 
         if counta == count:
             logs.系统日志("通过检查", PI)
@@ -288,8 +302,7 @@ def passwordsys(模式: any, id_protect: str, password_a: str):
         else:
             logs.系统日志(f"Fishconsole》passwordsys》count is {count}", PI)
             logs.系统日志(f"Fishconsole》passwordsys》counta is {counta}", PI)
-            print(logs.颜色(logs.日志("你输入了非法字符（除1-0，a-z,空格以外其他全是），请检查后重新开始，加密失败"), 色选="红色"))
-            exit()
+            logs.安全退出(logs.日志("你输入了非法字符（除1-0，a-z,空格以外其他全是），请检查后重新开始，加密失败", 色选="红色"))
 
         logs.系统日志("查看加密后的内容", PI)
 
@@ -478,8 +491,8 @@ def passwordsys(模式: any, id_protect: str, password_a: str):
             logs.系统日志("密码验证成功", PI)
             return f"{text}"
         else:
-            print(logs.颜色(logs.日志("您的密码是错误的，请核对后重新输入"), 色选="红色"))
-            exit()
+            logs.安全退出(logs.日志("您的密码是错误的，请核对后重新输入"), 色选="红色")
+
 
 
 def 密码(模式, 原文, 密码: str = ""):
@@ -536,6 +549,12 @@ def 网易云音乐(歌单链接: list):
 
 
 def 排名(数据源: list, 第几个: int):
+    b=强制类型检测(数据源,"list")
+    if b:
+        1+1
+    else:
+        print(logs.日志(f"Fishconsole{fcv.version()}》Fishsys》排名》强制类型检测》请指定list类型的数据源","红色"))
+    第几个=int(第几个)
     第几个 = 第几个 - 1
     a = 数据源
     for i in range(len(a)):
@@ -583,7 +602,7 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc"):
             logs.系统日志("缓存》文件存在性检测》指定文件并未发现，将返回布尔类型的False")
             return False
     else:
-        logs.错误跟踪(["Fishconsole", "tool", "缓存"], "请使用合法的模式", 模式)
+        logs.错误跟踪(["Fishconsole", "Fishsys", "缓存"], "请使用合法的模式", 模式)
 
 
 def 字符转unicode(模式, 原文: str):
@@ -610,18 +629,7 @@ def 字符转unicode(模式, 原文: str):
     else:
         logs.错误跟踪(["Fishconsole", "字符串转unicode", "模式"], "请选择正确的模式", {模式})
 
-
-
-
-
-
-def 强制类型检测(任意变量,预期类型):
-    type值=str(type(任意变量))
-    变量类型=type值.split("'")[1]
-    if 变量类型==预期类型:
-        return True
-    else:
-        return False
+update.update()
 
 
 
@@ -644,77 +652,7 @@ def 强制类型检测(任意变量,预期类型):
 
 
 
-# 你要删我也没办法，反正如果出了什么错过了重大更新你就自己乐呵去呗
 
-# 这个不是模块，我们将会在导入该模块的时候顺序执行此处
-# sys是f_debug的强制更新的总开关，如果开启，更新器才会允许运行
-sys = fcv.f_debug()
-sys = sys["updata"]
 
-UPI = fcv.f_debug()
-UPI = UPI["updata"]
 
-if sys:
-    logs.系统日志("强制更新系统》强制更新系统启动", UPI)
-    logs.系统日志("强制更新系统》读取缓存信息", UPI)
-    config = 缓存(2)
-    if not config:
-        logs.系统日志("强制更新系统》缓存》缓存文件不存在，创建缓存文件", UPI)
-        # fup的意思是tool模块判断自己是否在之前检测过一次，如果检测过一次，就是修改为正，让它可
-        # +以在下一次检测到版本还是低的话继续保持未检测的状态，如果成功了，那就将False修改为ture，这个fupadta是独立的
 
-        # 而updata是helps.帮助弄过来的，它的用处就是让tool执行强制更新的操作
-        # 因为没有文件，所以我们在一开始就要创建文件，这个创建文件有一个规则，就是需要创建啥就写入啥，不要一股脑全写，因为这样就显得不高效
-        config = {"updata": True, "fup": False}
-        logs.系统日志("强制更新系统》首次运行，添加fup到缓存", UPI)
-        # 提取数据，其实也是初始化首次启动时要用的变量
-        fup = config["fup"]
-        fupdata = config["updata"]
-        # 当变量有点修改的时候我们就要进行保存，因为这样才能避免出现突如其来的故障
-        缓存(1, config)
-    else:
-        # 当缓存文件存在时执行的操作
-        logs.系统日志(f"缓存文件存在，尝试读取相关信息", UPI)
-        logs.系统日志(f"Fishconsole.fcc is {config}", UPI)
-        # 因为我们有文件了，我们就可以直接提取数据，但是难免会出现一些奇奇怪怪的情况，所以我们还要检测参数是否存在
-        fup = config.get("fup")
-        fupdata = config.get("updata")
-        logs.系统日志(f"fup is {fup}", UPI)
-        logs.系统日志(f"fupdata is {fupdata}", UPI)
-        if fupdata is None:
-            logs.系统日志("fupdata配置不存在，创建", UPI)
-            config["updata"] = True
-            缓存(1, config)
-        if fup is None:
-            logs.系统日志("fup配置不存在，创建", UPI)
-            config["fup"] = True
-            fup = config["fup"]
-            缓存(1, config)
-
-    # fupdata在前面的参数提取中就已经搞好了，现在我们只需要执行操作了
-    if fupdata:
-        logs.系统日志("这是updata值为True时执行的操作", UPI)
-        if fup:
-            print(logs.日志(f"》Fishconsole强制更新系统{fcv.version()}》tool 》您的版本过低，请更新至最新版本后重试", "红色"))
-            # 最原始的操作，大家引以为戒
-            # os.remove("Fishconsole.fcc")
-            logs.系统日志(f"fup is {fup}", UPI)
-            # 反转变量值，这样就可以在下一次执行的时候触发更新
-            config["fup"] = False
-            缓存(1, config)
-            exit()
-        else:
-            # 这是tool的复检
-            print(logs.日志(f"》Fishconsole强制更新系统{fcv.version()}》tool 》正在激活帮助及模块包更新检查工具", "红色"))
-            # 反转变量值，这样就可以在下一次时触发警告
-            config["fup"] = True
-            # 只要缓存出现一次变化，我们就要把他存到fcc当中，只有这样我们才能保证它在异常关闭的时候数据不会丢失
-            缓存(1, config)
-            helps.帮助()
-    else:
-        logs.系统日志("这是updata值为False时执行的操作", UPI)
-        config["fup"] = True
-        缓存(1, config)
-else:
-    # 这是关闭了更新时执行的操作
-    logs.日志("fcv_debug已取消强制更新系统的执行", "绿色")
