@@ -1,6 +1,6 @@
 import matplotlib.pyplot as plt
 from Fishconsole import fcv
-from Fishconsole import tool
+from Fishconsole import Fishsys
 from Fishconsole import helps
 from Fishconsole import logs
 
