@@ -2,6 +2,8 @@
 
 
 from Fishconsole import fcv
+import sys
+import  os
 
 
 def 颜色(text, 色选="None"):
@@ -79,20 +81,30 @@ def 分割线(标题, text, 色选="Nona"):
         return f"\n\n\n\n\n\n- {标题} -  {text}:\n--------------------------\n"
 
 
-def 错误跟踪(路径: list, 内容: str, 参数):
-    res = "||"
-    for a in 路径:
-        res = res + "》" + a
-    res = res + "》" + ":" + 内容 + " [" + 参数 + "]"
-    raise NotImplementedError(res)
+
 
 
 def 变量查看(变量名: str, 变量, 色选: str = "红色"):
+    行位置 = sys._getframe(1).f_lineno
+
+    type值=str(type(变量))
+    变量类型=type值.split("'")[1]
+
+
     print("="*63)
-    print(日志(f"  ||（{颜色('变量名', 色选)}：{变量名}）（{颜色('数据', 色选)}：{变量}）（{颜色('类型', 色选)}: {type(变量)}）||"))
+    print(日志(f"  ||（{颜色('变量名', 色选)}：{变量名}）（{颜色('数据', 色选)}：{变量}）（{颜色('类型', 色选)}: {变量类型}）（{颜色('位置', 色选)}:{行位置}）||"))
     print("="*63+"\n\n")
 
 
+
+def 安全退出(内容):
+        a=sys._getframe(1).f_lineno
+        sys.exit(日志(f"》Fishconsole {fcv.version()}安全退出》{内容} || line[{a}] ","红色"))
+
+
+
+
+
 # print(日志(123, 色选="红色"))
 # print(分割线("123","456","红色"))
 # 全局参数="红色"
