@@ -3,6 +3,7 @@ import easygui
 # 虽然没什么用，但是里面的强制更新系统可以很好的牵制调用
 from Fishconsole import Fishsys
 from Fishconsole import logs
+from  Fishconsole  import fcv
 logs.系统日志("用户调用了window模块")
 
 
@@ -15,6 +16,11 @@ def 弹窗(显示文字, 标题, 确认显示文字):
 
 
 def 选择对话框(显示文字, 标题, 选项: list, 图片地址: str = None):
+    a=Fishsys.强制类型检测(选项,"list")
+    if a:
+        1+1
+    else:
+        print(logs.日志(f"Fishconsole{fcv.version()}》window》选择对话框》强制类型检测》请指定list类型的数据源","红色"))
     显示文字 = str(显示文字)
     标题 = str(标题)
     返回 = easygui.buttonbox(image=图片地址, msg=显示文字, title=标题, choices=选项)
@@ -22,6 +28,11 @@ def 选择对话框(显示文字, 标题, 选项: list, 图片地址: str = None
 
 
 def 列表选择对话框(显示文字, 标题, 选项: list):
+    a=Fishsys.强制类型检测(选项,"list")
+    if a:
+        1+1
+    else:
+        print(logs.日志(f"Fishconsole{fcv.version()}》window》列表选择对话框》强制类型检测》请指定list类型的数据源","红色"))
     标题 = str(标题)
     返回 = easygui.multchoicebox(msg=显示文字, title=标题, choices=选项)
     return 返回
